#!/bin/sh
JNOTE_CONF="/home/pi/.jupyter/jupyter_lab_config.py"
ADD_JNOTE_CONF="jupyter_notebook.conf"

BK_DATE=`date "+%Y%m%d-%H%M%S"`

IS_EXIST_TRUE=1
IS_EXIST_FALSE=0
IS_ADD_TRUE=1
IS_ADD_FALSE=0

IS_DEBUG_FLG=0

ORG_JNOTE_CONF=${JNOTE_CONF}_${BK_DATE}


make_file() {
    CHK_MODE=$1
    MAKE_MODE=$2
    IN_FNAME=$3
    IN_FDATA=$4
    OUT_FNAME=$5

if [ ${IS_DEBUG_FLG} -eq 1 ]; then
    echo "#### CHK_MODE  =${CHK_MODE}"
    echo "#### IS_EXIST_TRUE  =${IS_EXIST_TRUE}"
    echo "#### MAKE_MODE =${MAKE_MODE}"
    echo "#### IN_FNAME  =${IN_FNAME}"
    echo "#### IN_FDATA  =${IN_FDATA}"
    echo "#### OUT_FNAME =${OUT_FNAME}"
fi

    # ファイルの存在チェックする場合
    if [ ${CHK_MODE} -eq ${IS_EXIST_TRUE} ]; then

if [ ${IS_DEBUG_FLG} -eq 1 ]; then
    echo "--- CHK_MOD IS_EXIST_TRUE"
fi
        # ファイルが存在しない場合はエラー
        if [ ! -e ${IN_FNAME} ]; then
            echo "${IN_FNAME} NOT found."
            return 1
        fi
    fi
    
if [ ${IS_DEBUG_FLG} -eq 1 ]; then
    echo "--- CHK_MOD IS_EXIST_FALSE"
fi
    if [ ${MAKE_MODE} -eq ${IS_ADD_TRUE} ]; then
        # 既存ファイルのバックアップ
        cp -p ${IN_FNAME} ${IN_FNAME}_${BK_DATE}
        rm -f ${IN_FNAME}
        cat ${IN_FNAME}_${BK_DATE} ${IN_FDATA} > ${OUT_FNAME}
    else
        cat ${IN_FDATA} > ${OUT_FNAME}
    fi

    return 0
}

#####
# main
#####


echo "###### EV3 x Chainer Start setup #####"

# ソフトウエアアップデート
echo "     ----- SW update start -----"
sudo apt update
echo Y | sudo apt upgrade
echo "     ----- SW update end -----"
sleep 1

# パッケージ導入
echo "     ----- PKG install start -----"
sudo apt install -y git gcc g++ make libssl-dev libbz2-dev libreadline-dev libsqlite3-dev zlib1g-dev libjpeg-dev libffi-dev
echo "     ----- PKG install end -----"
sleep 1

if [ ! -f ~/.profile ]; then
    echo "ファイルが存在しません[$HOME/.profile]"
    exit 1
else
    cp -p ~/.profile ~/.profile_${BK_DATE}
fi

echo "     ----- pyenv DL start -----"
git clone https://github.com/yyuu/pyenv.git  ~/.pyenv
echo 'export PYENV_ROOT="$HOME/.pyenv" ' >> ~/.profile
echo 'export PATH="$PYENV_ROOT/bin:$PATH" ' >> ~/.profile
echo 'eval "$(pyenv init -)" ' >> ~/.profile
echo "     ----- pyenv DL end -----"
sleep 1


echo "     ----- pyenv-virtualenv.git DL start -----"
# Githubからpyenv-virtualenvダウンロードおよび環境変数設定
git clone https://github.com/yyuu/pyenv-virtualenv.git ~/.pyenv/plugins/pyenv-virtualenv
echo 'eval "$(pyenv virtualenv-init -)" ' >> ~/.profile
echo "     ----- pyenv-virtualenv.git DL end -----"
sleep 1

echo "     ----- Python install start -----"
. ~/.profile
pyenv install 3.8.5
echo "     ----- Python install end -----"

sleep 2

git clone -b update-requirements https://github.com/pfnet-research/chainer-ev3.git
cd /home/pi/chainer-ev3/workspace
pyenv virtualenv 3.8.5 rpi2ev3
pyenv local rpi2ev3
pip install -U pip
pip install -r requirements.txt

# jupyterlabの導入
pip install jupyterlab
cd /home/pi/chainer-ev3/workspace
echo y | jupyter lab --generate-config

# jupyter_notebook_config.py内の記述を変更
# 追加対象ファイルあり、ファイルに追加モード
cd /home/pi/
make_file ${IS_EXIST_TRUE} ${IS_ADD_TRUE} ${JNOTE_CONF} ${ADD_JNOTE_CONF} ${JNOTE_CONF}

# raspi起動時にjupyterが起動するよう設定
# 追加対象ファイルあり、ファイルに追加モード
sudo cp jupyter.service.conf /etc/systemd/system/jupyter.service
sudo systemctl disable jupyter
sudo systemctl list-unit-files --type=service | grep jupyter 
sudo systemctl start jupyter
sudo systemctl enable jupyter

# EV3コンソール導入設定
# 追加対象ファイルあり、ファイルに追加モード
sudo cp rules.conf /etc/udev/rules.d/70-mindsensors-ev3-console.rules
sudo cp ev3console.conf /lib/udev/ev3console
sudo sh /lib/udev/ev3console
sudo gpasswd -a $USER dialout

sleep 2
echo "###### EV3 x Chainer End setup #####"

exit 0
